<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="az">
<context>
    <name></name>
    <message>
        <source>Delete</source>
        <translation type="vanished">Silmək</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="vanished">Tam ekran</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="vanished">Slayd-şou</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">İxrac</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="vanished">Kopyalamaq</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="vanished">Sevimlilər</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="vanished">Saat əqrəbi istiqamətinə döndərmək</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="vanished">Saat əqrəbinin əksinə döndərmək</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="vanished">Divar kağızı kimi təyin etmək</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="vanished">Fayl menecerində göstərmək</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="vanished">Fotoşəkil məlumatları</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="vanished">Video haqqında</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation type="vanished">Bərpa etmək</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Unnamed</source>
        <translation>Adsız</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İmtina</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Yaratmaq</translation>
    </message>
    <message>
        <source>New Album</source>
        <translation>Yeni albom</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>İmtina</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Silmək</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this album?</source>
        <translation>Bu albomu silmək istədiyinizə əminsiniz?</translation>
    </message>
</context>
<context>
    <name>AlbumLeftTabItem</name>
    <message>
        <source>Trash</source>
        <translation>Səbət</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Sevimlilər</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>İdxal</translation>
    </message>
</context>
<context>
    <name>AlbumView</name>
    <message>
        <source>Trash</source>
        <translation>Səbət</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Sevimlilər</translation>
    </message>
    <message>
        <source>Or drag photos here</source>
        <translation>Və ya fotoşəkilləri buraya atın</translation>
    </message>
    <message>
        <source>Import All</source>
        <translation>Hamısını idxal etmək</translation>
    </message>
    <message>
        <source>Import to:</source>
        <translation>Buraya idxal etmək:</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>İdxal</translation>
    </message>
    <message>
        <source>System Disk</source>
        <translation>Sistem diski</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Qalareya</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Disk məşğuldur, indi çıxarıla bilməz</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Yeni albom</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İmtina</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ötürmək</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Yüklənir...</translation>
    </message>
    <message>
        <source>The files will be permanently deleted after the days shown on them</source>
        <translation>Fayllar, onlarda göstərilən vaxt bitdikdən sonra birdəfəlik silinəcəkdir</translation>
    </message>
    <message>
        <source>Image classification</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Album</source>
        <translation>Albom</translation>
    </message>
</context>
<context>
    <name>CExportImageDialog</name>
    <message>
        <source>Cancel</source>
        <translation>İmtina</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Əvəzləmək</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>İxrac</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Şəkillər</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Sənədlər</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Endirmələr</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>İş Masas</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videolar</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musiqi</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Adı:</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>Burada saxlamaq:</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Formatı:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Keyfiyyəti:</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Saxlamaq</translation>
    </message>
    <message>
        <source>gif</source>
        <translation>gif</translation>
    </message>
    <message>
        <source>Select other directories</source>
        <translation>Başqa qovluqlar seçmək</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>File name cannot be empty</source>
        <translation>Fayl adı boş ola bilməz</translation>
    </message>
    <message>
        <source>already exists. Do you want to replace it?</source>
        <translation>artıq mövcuddur. Onu əvəzləmək istəyirsiniz?</translation>
    </message>
</context>
<context>
    <name>DBManager</name>
    <message>
        <source>Screen Capture</source>
        <translation>Ekran şəkli</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation>Rəsm çəkin</translation>
    </message>
    <message>
        <source>(copy)</source>
        <translation>(kopya)</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Drive</source>
        <translation>%1 sürücü</translation>
    </message>
    <message>
        <source>Blank %1 Disc</source>
        <translation>Boş %1 disk</translation>
    </message>
    <message>
        <source>%1 Encrypted</source>
        <translation>%1 şifrələnib</translation>
    </message>
    <message>
        <source>%1 Volume</source>
        <translation>%1 həcm</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>Save</source>
        <translation>Saxlamaq</translation>
    </message>
    <message>
        <source>Export Photos</source>
        <translation>Fotoşəkilləri ixrac etmək</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İmtina</translation>
    </message>
</context>
<context>
    <name>ImageEngineApi</name>
    <message>
        <source>Deleting...</source>
        <translation>Silinir...</translation>
    </message>
    <message>
        <source>Restoring...</source>
        <translation>Bərpa edilir...</translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>İmtina</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Silmək</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete this file?</source>
        <translation>Bu faylı həmişəlik silmək istədiyinizə əminsiniz?</translation>
    </message>
    <message>
        <source>You cannot restore it any longer</source>
        <translation>Artıq onu bərpa edə bilməyəcəksiniz</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete %1 files?</source>
        <translation>%1 faylı həmişəlik silmək istədiyinizə əminisiniz?</translation>
    </message>
    <message>
        <source>You cannot restore them any longer</source>
        <translation>Artıq onları bərpa edə bilməyəcəksiniz</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this file locally?</source>
        <translation>Siz bu faylı yerli diskdən silmək istədiyinizə əminsiniz?</translation>
    </message>
    <message>
        <source>You can restore it in the trash</source>
        <translation>Siz bunu səbətdən bərpa edə bilərsiniz</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 files locally?</source>
        <translation>%1 faylı yerli diskdən silmək istədiyinizə əminsiniz?</translation>
    </message>
    <message>
        <source>You can restore them in the trash</source>
        <translation>Siz onları səbətdən bərpa edə bilərsiniz</translation>
    </message>
</context>
<context>
    <name>ImgInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>Baza məlumatları</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Təfərrüatlar</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Şəkil məlumatı</translation>
    </message>
</context>
<context>
    <name>ImportTimeLineView</name>
    <message>
        <source>Import</source>
        <translation>İdxal</translation>
    </message>
    <message>
        <source>1 photo</source>
        <translation>1 şəkil</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1 video</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation>
            <numerusform>%n fotolar</numerusform>
            <numerusform>%n şəkillər</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation>
            <numerusform>%n videolar</numerusform>
            <numerusform>%n videolar</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation>
            <numerusform>%n elementlər</numerusform>
            <numerusform>%n elementlər</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ImportView</name>
    <message>
        <source>Import Photos and Videos</source>
        <translation>Şəkilləri və Videoları idxal edin</translation>
    </message>
    <message>
        <source>Or drag them here</source>
        <translation>Və ya onları buraya atın</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation>Bütün şəkillər və videolar</translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation>Heç bir şəkil və ya video tapılmadı</translation>
    </message>
</context>
<context>
    <name>LeftListView</name>
    <message>
        <source>Slide show</source>
        <translation>Slayd şou</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Adını dəyişmək</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>İxrac</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Silmək</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Qurğular</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Qalareya</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Albomlar</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Yeni albom</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Album is a fashion manager for viewing and organizing photos and videos.</source>
        <translation>Albom, videolara və şəkillərə baxmaq və onları idarə etmək üçün fotoşəkil idarəetmə alətidir.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Photos</source>
        <translation>Fotoşəkillər</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Tam ekran</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Kömək</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Fayl menecerində göstərmək</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Slayd şou</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopyalamaq</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Divar kağızı kimi təyin etmək</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Saat əqrəbi istiqamətinə döndərmək</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Saat əqrəbinin əksinə döndərmək</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Əvvəlki</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Növbəti</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Sevimlilər</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Sevimlilərdən çıxartmaq</translation>
    </message>
    <message>
        <source>Rename album</source>
        <translation>Albomun adını dəyişmək</translation>
    </message>
    <message>
        <source>Album “%1” removed</source>
        <translation>%1 albomu silindi</translation>
    </message>
    <message>
        <source>Successfully added to “%1”</source>
        <translation>Buraya uğurla əlavə edildi: %1</translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation>Uğurla idxal olundu</translation>
    </message>
    <message>
        <source>Import failed</source>
        <translation>İdxal alınmadı</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>İxrac alınmadı</translation>
    </message>
    <message>
        <source>Export successful</source>
        <translation>Uğurla ixrac olundu</translation>
    </message>
    <message>
        <source>All Photos</source>
        <translation>Bütün fotolar</translation>
    </message>
    <message>
        <source>Timelines</source>
        <translation>Vaxt şkalası</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Albomlar</translation>
    </message>
    <message>
        <source>Exit fullscreen/slideshow</source>
        <translation>Tam ekran və ya slayd rejimindən çıxmaq</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Qısayolları göstərmək</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Baxış</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>Hamısını seçmək</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Yaxınlaşdırmaq</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Uzaqlaşdırmaq</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Yeni albom</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Yuxarı səhifələmək</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Aşağı səhifələmək</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>İdxal edilir...</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation>Bütün şəkillər və videolar</translation>
    </message>
    <message>
        <source>Import Photos and Videos</source>
        <translation>Şəkilləri və Videoları idxal edin</translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation>Heç bir şəkil və ya video tapılmadı</translation>
    </message>
    <message>
        <source>Export photos</source>
        <translation>Fotoşəkilləri ixrac edin</translation>
    </message>
    <message>
        <source>Import photos/videos</source>
        <translation>Fotoşəkilləri/videoları idxal edin</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Silmək</translation>
    </message>
    <message>
        <source>Photo/Video info</source>
        <translation>Foto/video məlumatı</translation>
    </message>
    <message>
        <source>Import photos and videos</source>
        <translation>Fotoları və videoları idxal edin</translation>
    </message>
    <message>
        <source>Import folders</source>
        <translation>Qovluqları idxal edin</translation>
    </message>
    <message>
        <source>Import interrupted</source>
        <translation>İdxal yarımçıq kəsildi</translation>
    </message>
    <message>
        <source>Cannot add this path, please try another one</source>
        <translation>Bu yol əlavə edilə bilməz, lütfən başqa yolu yoxlayın</translation>
    </message>
    <message>
        <source>The path already exists</source>
        <translation>Bu yol artıq mövcuddur</translation>
    </message>
    <message>
        <source>Failed to restore %1 files: file name too long</source>
        <translation>%1 bərpa edilə bilmədi: fayl adı çox uzundur</translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Flash</source>
        <translation>Flash</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Növ</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Faylın ölçüsü</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Ölçülər</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Çəkilmə tarixi</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Dəyişdirilmə tarixi</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Ekspozisiya rejimi</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Ekspozisiya proqramı</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Ekspozisiya vaxtı</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Diafraqma</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Fokus məsafəsi</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Maks. diafraqma</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Ölçmə rejimi</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Bəyazlıq balansı</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Flaş işığın tarazlaşdırılması</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Kameranın modeli</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Linza modeli</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Rəng sahəsi</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Yarlıq</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Ad</translation>
    </message>
</context>
<context>
    <name>NoResultWidget</name>
    <message>
        <source>No results</source>
        <translation>Nəticə yoxdur</translation>
    </message>
</context>
<context>
    <name>PathManager</name>
    <message>
        <source>System Disk</source>
        <translation>Sistem diski</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Select</source>
        <translation>Seçmək</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>Seçimi ləğv etmək</translation>
    </message>
    <message>
        <source>%1/%2/%3</source>
        <translation>%1/%2/%3</translation>
    </message>
    <message>
        <source>Imported on</source>
        <translation>Buraya idxal olundu:</translation>
    </message>
    <message>
        <source> %1-%2-%3 %4</source>
        <translation> %1-%2-%3 %4</translation>
    </message>
    <message>
        <source>Imported on </source>
        <translation>Buraya idxal olundu: </translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Hamısını seçin</translation>
    </message>
    <message>
        <source>Unselect All</source>
        <translation>Bütün seçimləri ləğv edin</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İmtina</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Bərpa etmək</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Silmək</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Hamısı</translation>
    </message>
    <message>
        <source>Photos</source>
        <translation>Fotoşəkillər</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videolar</translation>
    </message>
    <message>
        <source>No results</source>
        <translation>Nəticələr yoxdur</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Sevimlilər</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Saat əqrəbinin əksinə döndərmək</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Saat əqrəbi istiqamətinə döndərmək</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>İdxal edilir...</translation>
    </message>
    <message>
        <source>%1/%2 items imported</source>
        <translation>%1/%2 element idxal edildi</translation>
    </message>
    <message>
        <source>%1/%2 items deleted</source>
        <translation>%1/%2 element silindi</translation>
    </message>
    <message>
        <source>%1 items imported, %2 items failed</source>
        <translation>%1 element idxal olundu, %2 element idxal eldilə bilmədi</translation>
    </message>
    <message>
        <source>1 photo selected</source>
        <translation>1 şəkil seçildi</translation>
    </message>
    <message>
        <source>1 video selected</source>
        <translation>1 video seçildi</translation>
    </message>
    <message>
        <source>The photo/video already exists</source>
        <translation>Şəkil və ya video artıq mövcuddur</translation>
    </message>
    <message numerus="yes">
        <source>%n photos selected</source>
        <translation>
            <numerusform>%n şəkillər seçildi</numerusform>
            <numerusform>%n şəkillər seçildi</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos selected</source>
        <translation>
            <numerusform>%n videolar  seçildi</numerusform>
            <numerusform>%n videolar seçildi</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items selected</source>
        <translation>
            <numerusform>%n elementlər seçildi</numerusform>
            <numerusform>%n elementlər seçildi</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 items imported, %2 items exist already</source>
        <translation>%1 element idxal olundu, %2 element artıq mövcuddur</translation>
    </message>
    <message>
        <source>%1/%2 items classifyed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scenery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Food</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Humans</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Animals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scene</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plants</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>No search results</source>
        <translation>Axtarış nəticəsi yoxdur</translation>
    </message>
    <message>
        <source>Slide Show</source>
        <translation>Slayd-şou</translation>
    </message>
    <message>
        <source>Search results</source>
        <translation>Axtarış nəticələri</translation>
    </message>
    <message>
        <source>1 photo found</source>
        <translation>1 şəkil tapıldı</translation>
    </message>
    <message numerus="yes">
        <source>%n videos found</source>
        <translation>
            <numerusform>%n video tapıldı</numerusform>
            <numerusform>%n video tapıldı</numerusform>
        </translation>
    </message>
    <message>
        <source>1 video found</source>
        <translation>1 video tapıldı</translation>
    </message>
    <message numerus="yes">
        <source>%n items found</source>
        <translation>
            <numerusform>%n element tapıldı</numerusform>
            <numerusform>%n element tapıldı</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n photos found</source>
        <translation>
            <numerusform>%n fotoşəkil tapıldı</numerusform>
            <numerusform>%n fotoşəkil tapıldı</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>1 photo</source>
        <translation>1 şəkil</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1 video</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation>
            <numerusform>%n şəkil</numerusform>
            <numerusform>%n şəkil</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation>
            <numerusform>%n video</numerusform>
            <numerusform>%n video</numerusform>
        </translation>
    </message>
    <message>
        <source>Importing: %1</source>
        <translation>İdxal olunur: %1</translation>
    </message>
    <message>
        <source>Exporting: %1</source>
        <translation>İxrac olunur:%2</translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <source>View</source>
        <translation>Baxış</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Tam ekran</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>İxrac</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Sevimlilər</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Sevimlilərdən çıxartmaq</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Saat əqrəbi istiqamətinə döndərmək</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Saat əqrəbinin əksinə döndərmək</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Fayl menecerində göstərmək</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Divar kağızı kimi təyin etmək</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Silmək</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Slayd-şou</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopyalamaq</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>Fotoşəkil məlumatları</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Alboma əlavə etmək</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Albomdan silmək</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Bərpa etmək</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Yeni albom</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Çap</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation>Video haqqında</translation>
    </message>
    <message>
        <source>days</source>
        <translation>günlər</translation>
    </message>
</context>
<context>
    <name>TimeLineView</name>
    <message>
        <source>1 photo</source>
        <translation>1 şəkil</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1 video</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation>
            <numerusform>%n şəkil</numerusform>
            <numerusform>%n şəkil</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation>
            <numerusform>%n şəkil</numerusform>
            <numerusform>%n şəkil</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation>
            <numerusform>%n element</numerusform>
            <numerusform>%n element</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>VideoInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>Baza məlumatları</translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation>Kodek haqqında</translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation>Audio haqqında</translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation>Video CodecID</translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation>Video CodeRate</translation>
    </message>
    <message>
        <source>FPS</source>
        <translation>FPS</translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation>Nisbət</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Görüntü imkanı</translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation>Audio CodecID</translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation>Audio CodeRate</translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation>Səs rəqəmi</translation>
    </message>
    <message>
        <source>Channels</source>
        <translation>Kanallar</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation>Sampling</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Dəyişdirilmə tarixi</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Növ</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Faylın ölçüsü</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Müddəti</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Yol</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation>Video haqqında</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Çəkilmə tarixi</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Ad</translation>
    </message>
</context>
</TS>
